# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_knowledge_entity_schemas_response import KnowledgeKnowledgeEntitySchemasResponse

class TestKnowledgeKnowledgeEntitySchemasResponse(unittest.TestCase):
    """KnowledgeKnowledgeEntitySchemasResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeKnowledgeEntitySchemasResponse:
        """Test KnowledgeKnowledgeEntitySchemasResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeKnowledgeEntitySchemasResponse`
        """
        model = KnowledgeKnowledgeEntitySchemasResponse()
        if include_optional:
            return KnowledgeKnowledgeEntitySchemasResponse(
                error = '',
                schemas = [
                    neurograph.v1.models.knowledge/knowledge_entity_schema_row.knowledge.KnowledgeEntitySchemaRow(
                        description = '', 
                        json_schema = neurograph.v1.models.json_schema.json_schema(), 
                        params_example = neurograph.v1.models.params_example.params_example(), 
                        schema_id = '', 
                        source_system = '', 
                        ts_created = 56, 
                        ts_updated = 56, )
                    ]
            )
        else:
            return KnowledgeKnowledgeEntitySchemasResponse(
        )
        """

    def testKnowledgeKnowledgeEntitySchemasResponse(self):
        """Test KnowledgeKnowledgeEntitySchemasResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient
from neurograph.v1.models.client_client_get_detail_response import ClientClientGetDetailResponse
from neurograph.v1.models.client_client_get_many_response import ClientClientGetManyResponse
from neurograph.v1.models.client_client_info import ClientClientInfo
from neurograph.v1.models.client_client_metadata_request import ClientClientMetadataRequest
from neurograph.v1.models.client_client_metadata_response import ClientClientMetadataResponse
from neurograph.v1.models.client_client_personas_response import ClientClientPersonasResponse
from neurograph.v1.models.client_client_upsert_request import ClientClientUpsertRequest
from neurograph.v1.models.client_client_upsert_response import ClientClientUpsertResponse
from neurograph.v1.models.client_client_url_upsert_request import ClientClientUrlUpsertRequest
from neurograph.v1.models.client_client_url_upsert_response import ClientClientUrlUpsertResponse
from neurograph.v1.models.client_client_urls_response import ClientClientUrlsResponse
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest
from neurograph.v1.models.client_kpi import ClientKpi
from neurograph.v1.models.client_metadata import ClientMetadata
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait
from neurograph.v1.models.client_query import ClientQuery
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig
from neurograph.v1.models.dagster_dagster_info import DagsterDagsterInfo
from neurograph.v1.models.dagster_dagster_log_create_request import DagsterDagsterLogCreateRequest
from neurograph.v1.models.dagster_dagster_log_create_response import DagsterDagsterLogCreateResponse
from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse
from neurograph.v1.models.db_client_url import DbClientUrl
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams
from neurograph.v1.models.knowledge_err_entity_row import KnowledgeErrEntityRow
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_knowledge_entity import KnowledgeKnowledgeEntity
from neurograph.v1.models.knowledge_knowledge_entity_create_request import KnowledgeKnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_knowledge_entity_create_response import KnowledgeKnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_knowledge_entity_extra import KnowledgeKnowledgeEntityExtra
from neurograph.v1.models.knowledge_knowledge_entity_get_many_response import KnowledgeKnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_knowledge_entity_in_db import KnowledgeKnowledgeEntityInDb
from neurograph.v1.models.knowledge_knowledge_entity_relations import KnowledgeKnowledgeEntityRelations
from neurograph.v1.models.knowledge_knowledge_entity_schema import KnowledgeKnowledgeEntitySchema
from neurograph.v1.models.knowledge_knowledge_entity_schema_row import KnowledgeKnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_knowledge_entity_schema_upsert_request import KnowledgeKnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_knowledge_entity_schemas_response import KnowledgeKnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_knowledge_entity_schemas_upsert_response import KnowledgeKnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_knowledge_entity_type_row import KnowledgeKnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_knowledge_entity_upsert_request import KnowledgeKnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_knowledge_entity_upsert_row import KnowledgeKnowledgeEntityUpsertRow
from neurograph.v1.models.knowledge_knowledge_ingest_raw_request import KnowledgeKnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_knowledge_ingest_raw_response import KnowledgeKnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_knowledge_kind_response import KnowledgeKnowledgeKindResponse
from neurograph.v1.models.knowledge_knowledge_type_response import KnowledgeKnowledgeTypeResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery
from neurograph.v1.models.lookup_language import LookupLanguage
from neurograph.v1.models.lookup_lookup_language_response import LookupLookupLanguageResponse
from neurograph.v1.models.lookup_lookup_state_response import LookupLookupStateResponse
from neurograph.v1.models.lookup_state import LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata
from neurograph.v1.models.organizations_organization import OrganizationsOrganization
from neurograph.v1.models.organizations_organization_brand import OrganizationsOrganizationBrand
from neurograph.v1.models.organizations_organization_create_request import OrganizationsOrganizationCreateRequest
from neurograph.v1.models.organizations_organization_detail_response import OrganizationsOrganizationDetailResponse
from neurograph.v1.models.organizations_organization_get_many_response import OrganizationsOrganizationGetManyResponse
from neurograph.v1.models.organizations_organization_metadata_request import OrganizationsOrganizationMetadataRequest
from neurograph.v1.models.organizations_organization_metadata_response import OrganizationsOrganizationMetadataResponse
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_delete_many_persona_instances_request import PersonasDeleteManyPersonaInstancesRequest
from neurograph.v1.models.personas_kpi import PersonasKpi
from neurograph.v1.models.personas_match_criteria_row import PersonasMatchCriteriaRow
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_persona import PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor
from neurograph.v1.models.personas_persona_factor_create_request import PersonasPersonaFactorCreateRequest
from neurograph.v1.models.personas_persona_factor_create_response import PersonasPersonaFactorCreateResponse
from neurograph.v1.models.personas_persona_factor_resp import PersonasPersonaFactorResp
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight
from neurograph.v1.models.personas_persona_insight_create_request import PersonasPersonaInsightCreateRequest
from neurograph.v1.models.personas_persona_insight_create_response import PersonasPersonaInsightCreateResponse
from neurograph.v1.models.personas_persona_instance_create_request import PersonasPersonaInstanceCreateRequest
from neurograph.v1.models.personas_persona_instance_create_response import PersonasPersonaInstanceCreateResponse
from neurograph.v1.models.personas_persona_instances_delete_response import PersonasPersonaInstancesDeleteResponse
from neurograph.v1.models.personas_persona_instances_response import PersonasPersonaInstancesResponse
from neurograph.v1.models.personas_persona_kpi_create_request import PersonasPersonaKpiCreateRequest
from neurograph.v1.models.personas_persona_kpi_create_response import PersonasPersonaKpiCreateResponse
from neurograph.v1.models.personas_persona_kpi_req import PersonasPersonaKpiReq
from neurograph.v1.models.personas_persona_kpi_resp import PersonasPersonaKpiResp
from neurograph.v1.models.personas_persona_match_criteria_request import PersonasPersonaMatchCriteriaRequest
from neurograph.v1.models.personas_persona_match_criteria_response import PersonasPersonaMatchCriteriaResponse
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_persona_seed_create_request import PersonasPersonaSeedCreateRequest
from neurograph.v1.models.personas_persona_seed_create_response import PersonasPersonaSeedCreateResponse
from neurograph.v1.models.personas_persona_seed_get_many_response import PersonasPersonaSeedGetManyResponse
from neurograph.v1.models.personas_persona_seeds_delete_request import PersonasPersonaSeedsDeleteRequest
from neurograph.v1.models.personas_persona_seeds_delete_response import PersonasPersonaSeedsDeleteResponse
from neurograph.v1.models.personas_persona_trait_create_request import PersonasPersonaTraitCreateRequest
from neurograph.v1.models.personas_persona_trait_create_response import PersonasPersonaTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in import PersonasPersonalityTraitIn
from neurograph.v1.models.personas_personality_trait_out import PersonasPersonalityTraitOut
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
from neurograph.v1.models.tasks_sync_from_firebase_result import TasksSyncFromFirebaseResult
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest



# coding: utf-8

# flake8: noqa

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AuthenticationApi",
    "ClientApi",
    "ClientMetadataApi",
    "DagsterApi",
    "KnowledgeApi",
    "LookupApi",
    "OrganizationApi",
    "OrganizationMetadataApi",
    "PersonaApi",
    "SystemApi",
    "TasksApi",
    "WorkbenchApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AuthServiceTokenRequest",
    "AuthTestServiceTokenRequest",
    "AuthTestServiceTokenResponse",
    "AuthTestTokenResponse",
    "ClientClient",
    "ClientClientGetDetailResponse",
    "ClientClientGetManyResponse",
    "ClientClientInfo",
    "ClientClientMetadataRequest",
    "ClientClientMetadataResponse",
    "ClientClientPersonasResponse",
    "ClientClientUpsertRequest",
    "ClientClientUpsertResponse",
    "ClientClientUrlUpsertRequest",
    "ClientClientUrlUpsertResponse",
    "ClientClientUrlsResponse",
    "ClientDeleteMetadataRequest",
    "ClientKpi",
    "ClientMetadata",
    "ClientOrganizationBrand",
    "ClientOrganizationDetail",
    "ClientPersona",
    "ClientPersonaFactor",
    "ClientPersonaInsight",
    "ClientPersonaPersonalityTrait",
    "ClientQuery",
    "ClientWorkbenchConfig",
    "DagsterDagsterInfo",
    "DagsterDagsterLogCreateRequest",
    "DagsterDagsterLogCreateResponse",
    "DagsterDagsterLogGetResponse",
    "DbClientUrl",
    "DbPersonaFactorCreateParams",
    "KnowledgeErrEntityRow",
    "KnowledgeIngestRawRow",
    "KnowledgeKnowledgeEntity",
    "KnowledgeKnowledgeEntityCreateRequest",
    "KnowledgeKnowledgeEntityCreateResponse",
    "KnowledgeKnowledgeEntityExtra",
    "KnowledgeKnowledgeEntityGetManyResponse",
    "KnowledgeKnowledgeEntityInDb",
    "KnowledgeKnowledgeEntityRelations",
    "KnowledgeKnowledgeEntitySchema",
    "KnowledgeKnowledgeEntitySchemaRow",
    "KnowledgeKnowledgeEntitySchemaUpsertRequest",
    "KnowledgeKnowledgeEntitySchemasResponse",
    "KnowledgeKnowledgeEntitySchemasUpsertResponse",
    "KnowledgeKnowledgeEntityTypeRow",
    "KnowledgeKnowledgeEntityUpsertRequest",
    "KnowledgeKnowledgeEntityUpsertRow",
    "KnowledgeKnowledgeIngestRawRequest",
    "KnowledgeKnowledgeIngestRawResponse",
    "KnowledgeKnowledgeKindResponse",
    "KnowledgeKnowledgeTypeResponse",
    "KnowledgeQuery",
    "LookupLanguage",
    "LookupLookupLanguageResponse",
    "LookupLookupStateResponse",
    "LookupState",
    "LookupStateResponse",
    "OrganizationsBrandDetailResponse",
    "OrganizationsBrandUpsertRequest",
    "OrganizationsDeleteMetadataRequest",
    "OrganizationsDeleteMetadataResponse",
    "OrganizationsMetadata",
    "OrganizationsOrganization",
    "OrganizationsOrganizationBrand",
    "OrganizationsOrganizationCreateRequest",
    "OrganizationsOrganizationDetailResponse",
    "OrganizationsOrganizationGetManyResponse",
    "OrganizationsOrganizationMetadataRequest",
    "OrganizationsOrganizationMetadataResponse",
    "OrganizationsOrganizationSetWorkbenchRequest",
    "OrganizationsOrganizationSetWorkbenchResponse",
    "OrganizationsOrganizationUpdateRequest",
    "OrganizationsWorkbenchConfig",
    "PersonasDeleteManyPersonaInstancesRequest",
    "PersonasKpi",
    "PersonasMatchCriteriaRow",
    "PersonasMatchCriteriaRowIn",
    "PersonasPersona",
    "PersonasPersonaFactor",
    "PersonasPersonaFactorCreateRequest",
    "PersonasPersonaFactorCreateResponse",
    "PersonasPersonaFactorResp",
    "PersonasPersonaInsight",
    "PersonasPersonaInsightCreateRequest",
    "PersonasPersonaInsightCreateResponse",
    "PersonasPersonaInstanceCreateRequest",
    "PersonasPersonaInstanceCreateResponse",
    "PersonasPersonaInstancesDeleteResponse",
    "PersonasPersonaInstancesResponse",
    "PersonasPersonaKpiCreateRequest",
    "PersonasPersonaKpiCreateResponse",
    "PersonasPersonaKpiReq",
    "PersonasPersonaKpiResp",
    "PersonasPersonaMatchCriteriaRequest",
    "PersonasPersonaMatchCriteriaResponse",
    "PersonasPersonaPersonalityTrait",
    "PersonasPersonaSeedCreateRequest",
    "PersonasPersonaSeedCreateResponse",
    "PersonasPersonaSeedGetManyResponse",
    "PersonasPersonaSeedsDeleteRequest",
    "PersonasPersonaSeedsDeleteResponse",
    "PersonasPersonaTraitCreateRequest",
    "PersonasPersonaTraitCreateResponse",
    "PersonasPersonalityTraitIn",
    "PersonasPersonalityTraitOut",
    "PgtypeInfinityModifier",
    "PgtypeTimestamp",
    "TasksSyncFromFirebaseResult",
    "WorkbenchWorkbenchUrlCheckRequest",
    "WorkbenchWorkbenchUrlCheckResponse",
    "WorkbenchWorkbenchVersion",
    "WorkbenchWorkbenchVersionManyResponse",
    "WorkbenchWorkbenchVersionResponse",
    "WorkbenchWorkbenchVersionUpsertRequest",
]

# import apis into sdk package
from neurograph.v1.api.authentication_api import AuthenticationApi as AuthenticationApi
from neurograph.v1.api.client_api import ClientApi as ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi as ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi as DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi as KnowledgeApi
from neurograph.v1.api.lookup_api import LookupApi as LookupApi
from neurograph.v1.api.organization_api import OrganizationApi as OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi as OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi as PersonaApi
from neurograph.v1.api.system_api import SystemApi as SystemApi
from neurograph.v1.api.tasks_api import TasksApi as TasksApi
from neurograph.v1.api.workbench_api import WorkbenchApi as WorkbenchApi

# import ApiClient
from neurograph.v1.api_response import ApiResponse as ApiResponse
from neurograph.v1.api_client import ApiClient as ApiClient
from neurograph.v1.configuration import Configuration as Configuration
from neurograph.v1.exceptions import OpenApiException as OpenApiException
from neurograph.v1.exceptions import ApiTypeError as ApiTypeError
from neurograph.v1.exceptions import ApiValueError as ApiValueError
from neurograph.v1.exceptions import ApiKeyError as ApiKeyError
from neurograph.v1.exceptions import ApiAttributeError as ApiAttributeError
from neurograph.v1.exceptions import ApiException as ApiException

# import models into sdk package
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest as AuthServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest as AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse as AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse as AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient as ClientClient
from neurograph.v1.models.client_client_get_detail_response import ClientClientGetDetailResponse as ClientClientGetDetailResponse
from neurograph.v1.models.client_client_get_many_response import ClientClientGetManyResponse as ClientClientGetManyResponse
from neurograph.v1.models.client_client_info import ClientClientInfo as ClientClientInfo
from neurograph.v1.models.client_client_metadata_request import ClientClientMetadataRequest as ClientClientMetadataRequest
from neurograph.v1.models.client_client_metadata_response import ClientClientMetadataResponse as ClientClientMetadataResponse
from neurograph.v1.models.client_client_personas_response import ClientClientPersonasResponse as ClientClientPersonasResponse
from neurograph.v1.models.client_client_upsert_request import ClientClientUpsertRequest as ClientClientUpsertRequest
from neurograph.v1.models.client_client_upsert_response import ClientClientUpsertResponse as ClientClientUpsertResponse
from neurograph.v1.models.client_client_url_upsert_request import ClientClientUrlUpsertRequest as ClientClientUrlUpsertRequest
from neurograph.v1.models.client_client_url_upsert_response import ClientClientUrlUpsertResponse as ClientClientUrlUpsertResponse
from neurograph.v1.models.client_client_urls_response import ClientClientUrlsResponse as ClientClientUrlsResponse
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest as ClientDeleteMetadataRequest
from neurograph.v1.models.client_kpi import ClientKpi as ClientKpi
from neurograph.v1.models.client_metadata import ClientMetadata as ClientMetadata
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand as ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail as ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona as ClientPersona
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor as ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight as ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait as ClientPersonaPersonalityTrait
from neurograph.v1.models.client_query import ClientQuery as ClientQuery
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig as ClientWorkbenchConfig
from neurograph.v1.models.dagster_dagster_info import DagsterDagsterInfo as DagsterDagsterInfo
from neurograph.v1.models.dagster_dagster_log_create_request import DagsterDagsterLogCreateRequest as DagsterDagsterLogCreateRequest
from neurograph.v1.models.dagster_dagster_log_create_response import DagsterDagsterLogCreateResponse as DagsterDagsterLogCreateResponse
from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse as DagsterDagsterLogGetResponse
from neurograph.v1.models.db_client_url import DbClientUrl as DbClientUrl
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams as DbPersonaFactorCreateParams
from neurograph.v1.models.knowledge_err_entity_row import KnowledgeErrEntityRow as KnowledgeErrEntityRow
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow as KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_knowledge_entity import KnowledgeKnowledgeEntity as KnowledgeKnowledgeEntity
from neurograph.v1.models.knowledge_knowledge_entity_create_request import KnowledgeKnowledgeEntityCreateRequest as KnowledgeKnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_knowledge_entity_create_response import KnowledgeKnowledgeEntityCreateResponse as KnowledgeKnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_knowledge_entity_extra import KnowledgeKnowledgeEntityExtra as KnowledgeKnowledgeEntityExtra
from neurograph.v1.models.knowledge_knowledge_entity_get_many_response import KnowledgeKnowledgeEntityGetManyResponse as KnowledgeKnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_knowledge_entity_in_db import KnowledgeKnowledgeEntityInDb as KnowledgeKnowledgeEntityInDb
from neurograph.v1.models.knowledge_knowledge_entity_relations import KnowledgeKnowledgeEntityRelations as KnowledgeKnowledgeEntityRelations
from neurograph.v1.models.knowledge_knowledge_entity_schema import KnowledgeKnowledgeEntitySchema as KnowledgeKnowledgeEntitySchema
from neurograph.v1.models.knowledge_knowledge_entity_schema_row import KnowledgeKnowledgeEntitySchemaRow as KnowledgeKnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_knowledge_entity_schema_upsert_request import KnowledgeKnowledgeEntitySchemaUpsertRequest as KnowledgeKnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_knowledge_entity_schemas_response import KnowledgeKnowledgeEntitySchemasResponse as KnowledgeKnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_knowledge_entity_schemas_upsert_response import KnowledgeKnowledgeEntitySchemasUpsertResponse as KnowledgeKnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_knowledge_entity_type_row import KnowledgeKnowledgeEntityTypeRow as KnowledgeKnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_knowledge_entity_upsert_request import KnowledgeKnowledgeEntityUpsertRequest as KnowledgeKnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_knowledge_entity_upsert_row import KnowledgeKnowledgeEntityUpsertRow as KnowledgeKnowledgeEntityUpsertRow
from neurograph.v1.models.knowledge_knowledge_ingest_raw_request import KnowledgeKnowledgeIngestRawRequest as KnowledgeKnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_knowledge_ingest_raw_response import KnowledgeKnowledgeIngestRawResponse as KnowledgeKnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_knowledge_kind_response import KnowledgeKnowledgeKindResponse as KnowledgeKnowledgeKindResponse
from neurograph.v1.models.knowledge_knowledge_type_response import KnowledgeKnowledgeTypeResponse as KnowledgeKnowledgeTypeResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery as KnowledgeQuery
from neurograph.v1.models.lookup_language import LookupLanguage as LookupLanguage
from neurograph.v1.models.lookup_lookup_language_response import LookupLookupLanguageResponse as LookupLookupLanguageResponse
from neurograph.v1.models.lookup_lookup_state_response import LookupLookupStateResponse as LookupLookupStateResponse
from neurograph.v1.models.lookup_state import LookupState as LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse as LookupStateResponse
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse as OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest as OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest as OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse as OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata as OrganizationsMetadata
from neurograph.v1.models.organizations_organization import OrganizationsOrganization as OrganizationsOrganization
from neurograph.v1.models.organizations_organization_brand import OrganizationsOrganizationBrand as OrganizationsOrganizationBrand
from neurograph.v1.models.organizations_organization_create_request import OrganizationsOrganizationCreateRequest as OrganizationsOrganizationCreateRequest
from neurograph.v1.models.organizations_organization_detail_response import OrganizationsOrganizationDetailResponse as OrganizationsOrganizationDetailResponse
from neurograph.v1.models.organizations_organization_get_many_response import OrganizationsOrganizationGetManyResponse as OrganizationsOrganizationGetManyResponse
from neurograph.v1.models.organizations_organization_metadata_request import OrganizationsOrganizationMetadataRequest as OrganizationsOrganizationMetadataRequest
from neurograph.v1.models.organizations_organization_metadata_response import OrganizationsOrganizationMetadataResponse as OrganizationsOrganizationMetadataResponse
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest as OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse as OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest as OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig as OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_delete_many_persona_instances_request import PersonasDeleteManyPersonaInstancesRequest as PersonasDeleteManyPersonaInstancesRequest
from neurograph.v1.models.personas_kpi import PersonasKpi as PersonasKpi
from neurograph.v1.models.personas_match_criteria_row import PersonasMatchCriteriaRow as PersonasMatchCriteriaRow
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn as PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_persona import PersonasPersona as PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor as PersonasPersonaFactor
from neurograph.v1.models.personas_persona_factor_create_request import PersonasPersonaFactorCreateRequest as PersonasPersonaFactorCreateRequest
from neurograph.v1.models.personas_persona_factor_create_response import PersonasPersonaFactorCreateResponse as PersonasPersonaFactorCreateResponse
from neurograph.v1.models.personas_persona_factor_resp import PersonasPersonaFactorResp as PersonasPersonaFactorResp
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight as PersonasPersonaInsight
from neurograph.v1.models.personas_persona_insight_create_request import PersonasPersonaInsightCreateRequest as PersonasPersonaInsightCreateRequest
from neurograph.v1.models.personas_persona_insight_create_response import PersonasPersonaInsightCreateResponse as PersonasPersonaInsightCreateResponse
from neurograph.v1.models.personas_persona_instance_create_request import PersonasPersonaInstanceCreateRequest as PersonasPersonaInstanceCreateRequest
from neurograph.v1.models.personas_persona_instance_create_response import PersonasPersonaInstanceCreateResponse as PersonasPersonaInstanceCreateResponse
from neurograph.v1.models.personas_persona_instances_delete_response import PersonasPersonaInstancesDeleteResponse as PersonasPersonaInstancesDeleteResponse
from neurograph.v1.models.personas_persona_instances_response import PersonasPersonaInstancesResponse as PersonasPersonaInstancesResponse
from neurograph.v1.models.personas_persona_kpi_create_request import PersonasPersonaKpiCreateRequest as PersonasPersonaKpiCreateRequest
from neurograph.v1.models.personas_persona_kpi_create_response import PersonasPersonaKpiCreateResponse as PersonasPersonaKpiCreateResponse
from neurograph.v1.models.personas_persona_kpi_req import PersonasPersonaKpiReq as PersonasPersonaKpiReq
from neurograph.v1.models.personas_persona_kpi_resp import PersonasPersonaKpiResp as PersonasPersonaKpiResp
from neurograph.v1.models.personas_persona_match_criteria_request import PersonasPersonaMatchCriteriaRequest as PersonasPersonaMatchCriteriaRequest
from neurograph.v1.models.personas_persona_match_criteria_response import PersonasPersonaMatchCriteriaResponse as PersonasPersonaMatchCriteriaResponse
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait as PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_persona_seed_create_request import PersonasPersonaSeedCreateRequest as PersonasPersonaSeedCreateRequest
from neurograph.v1.models.personas_persona_seed_create_response import PersonasPersonaSeedCreateResponse as PersonasPersonaSeedCreateResponse
from neurograph.v1.models.personas_persona_seed_get_many_response import PersonasPersonaSeedGetManyResponse as PersonasPersonaSeedGetManyResponse
from neurograph.v1.models.personas_persona_seeds_delete_request import PersonasPersonaSeedsDeleteRequest as PersonasPersonaSeedsDeleteRequest
from neurograph.v1.models.personas_persona_seeds_delete_response import PersonasPersonaSeedsDeleteResponse as PersonasPersonaSeedsDeleteResponse
from neurograph.v1.models.personas_persona_trait_create_request import PersonasPersonaTraitCreateRequest as PersonasPersonaTraitCreateRequest
from neurograph.v1.models.personas_persona_trait_create_response import PersonasPersonaTraitCreateResponse as PersonasPersonaTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in import PersonasPersonalityTraitIn as PersonasPersonalityTraitIn
from neurograph.v1.models.personas_personality_trait_out import PersonasPersonalityTraitOut as PersonasPersonalityTraitOut
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier as PgtypeInfinityModifier
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp as PgtypeTimestamp
from neurograph.v1.models.tasks_sync_from_firebase_result import TasksSyncFromFirebaseResult as TasksSyncFromFirebaseResult
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest as WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse as WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion as WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse as WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse as WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest as WorkbenchWorkbenchVersionUpsertRequest



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from neurograph.v1.models.knowledge_knowledge_entity_create_request import KnowledgeKnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_knowledge_entity_create_response import KnowledgeKnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_knowledge_entity_get_many_response import KnowledgeKnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_knowledge_entity_schema_upsert_request import KnowledgeKnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_knowledge_entity_schemas_response import KnowledgeKnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_knowledge_entity_schemas_upsert_response import KnowledgeKnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_knowledge_entity_upsert_request import KnowledgeKnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_knowledge_ingest_raw_request import KnowledgeKnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_knowledge_ingest_raw_response import KnowledgeKnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_knowledge_kind_response import KnowledgeKnowledgeKindResponse
from neurograph.v1.models.knowledge_knowledge_type_response import KnowledgeKnowledgeTypeResponse

from neurograph.v1.api_client import ApiClient, RequestSerialized
from neurograph.v1.api_response import ApiResponse
from neurograph.v1.rest import RESTResponseType


class KnowledgeApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_knowledge_entity_get(
        self,
        client_id: Optional[StrictStr] = None,
        kind: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        schema_id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeEntityGetManyResponse:
        """Get Knowledge Entities

        Get one or many knowledge Entities, up to 10mb per request

        :param client_id:
        :type client_id: str
        :param kind:
        :type kind: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param schema_id:
        :type schema_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_entity_get_serialize(
            client_id=client_id,
            kind=kind,
            limit=limit,
            offset=offset,
            schema_id=schema_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntityGetManyResponse",
            '400': "KnowledgeKnowledgeEntityGetManyResponse",
            '503': "KnowledgeKnowledgeEntityGetManyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_entity_get_with_http_info(
        self,
        client_id: Optional[StrictStr] = None,
        kind: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        schema_id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeEntityGetManyResponse]:
        """Get Knowledge Entities

        Get one or many knowledge Entities, up to 10mb per request

        :param client_id:
        :type client_id: str
        :param kind:
        :type kind: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param schema_id:
        :type schema_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_entity_get_serialize(
            client_id=client_id,
            kind=kind,
            limit=limit,
            offset=offset,
            schema_id=schema_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntityGetManyResponse",
            '400': "KnowledgeKnowledgeEntityGetManyResponse",
            '503': "KnowledgeKnowledgeEntityGetManyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_entity_get_without_preload_content(
        self,
        client_id: Optional[StrictStr] = None,
        kind: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        schema_id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Knowledge Entities

        Get one or many knowledge Entities, up to 10mb per request

        :param client_id:
        :type client_id: str
        :param kind:
        :type kind: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param schema_id:
        :type schema_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_entity_get_serialize(
            client_id=client_id,
            kind=kind,
            limit=limit,
            offset=offset,
            schema_id=schema_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntityGetManyResponse",
            '400': "KnowledgeKnowledgeEntityGetManyResponse",
            '503': "KnowledgeKnowledgeEntityGetManyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_entity_get_serialize(
        self,
        client_id,
        kind,
        limit,
        offset,
        schema_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if client_id is not None:
            
            _query_params.append(('clientId', client_id))
            
        if kind is not None:
            
            _query_params.append(('kind', kind))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if schema_id is not None:
            
            _query_params.append(('schemaId', schema_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/knowledge/entity/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_entity_post(
        self,
        request: Annotated[KnowledgeKnowledgeEntityCreateRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeEntityCreateResponse:
        """Create Knowledge Entities

        Create one or many knowledge Entities, up to 10mb per request

        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntityCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_entity_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntityCreateResponse",
            '400': "KnowledgeKnowledgeEntityCreateResponse",
            '503': "KnowledgeKnowledgeEntityCreateResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_entity_post_with_http_info(
        self,
        request: Annotated[KnowledgeKnowledgeEntityCreateRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeEntityCreateResponse]:
        """Create Knowledge Entities

        Create one or many knowledge Entities, up to 10mb per request

        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntityCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_entity_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntityCreateResponse",
            '400': "KnowledgeKnowledgeEntityCreateResponse",
            '503': "KnowledgeKnowledgeEntityCreateResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_entity_post_without_preload_content(
        self,
        request: Annotated[KnowledgeKnowledgeEntityCreateRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Knowledge Entities

        Create one or many knowledge Entities, up to 10mb per request

        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntityCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_entity_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntityCreateResponse",
            '400': "KnowledgeKnowledgeEntityCreateResponse",
            '503': "KnowledgeKnowledgeEntityCreateResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_entity_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/knowledge/entity/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_ingest_raw_post(
        self,
        request: Annotated[KnowledgeKnowledgeIngestRawRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeIngestRawResponse:
        """Ingest raw source payloads

        Append raw payloads into knowledge.ingest_raw (deduped by conflict key)

        :param request: Body (required)
        :type request: KnowledgeKnowledgeIngestRawRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_ingest_raw_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeIngestRawResponse",
            '400': "KnowledgeKnowledgeIngestRawResponse",
            '503': "KnowledgeKnowledgeIngestRawResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_ingest_raw_post_with_http_info(
        self,
        request: Annotated[KnowledgeKnowledgeIngestRawRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeIngestRawResponse]:
        """Ingest raw source payloads

        Append raw payloads into knowledge.ingest_raw (deduped by conflict key)

        :param request: Body (required)
        :type request: KnowledgeKnowledgeIngestRawRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_ingest_raw_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeIngestRawResponse",
            '400': "KnowledgeKnowledgeIngestRawResponse",
            '503': "KnowledgeKnowledgeIngestRawResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_ingest_raw_post_without_preload_content(
        self,
        request: Annotated[KnowledgeKnowledgeIngestRawRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Ingest raw source payloads

        Append raw payloads into knowledge.ingest_raw (deduped by conflict key)

        :param request: Body (required)
        :type request: KnowledgeKnowledgeIngestRawRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_ingest_raw_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeIngestRawResponse",
            '400': "KnowledgeKnowledgeIngestRawResponse",
            '503': "KnowledgeKnowledgeIngestRawResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_ingest_raw_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/knowledge/ingest-raw/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_kind_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeKindResponse:
        """Get Knowledge Kinds

        Knowledge kinds are an enum of the valid knowledg entity 'kind' field

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_kind_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeKindResponse",
            '400': "KnowledgeKnowledgeKindResponse",
            '503': "KnowledgeKnowledgeKindResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_kind_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeKindResponse]:
        """Get Knowledge Kinds

        Knowledge kinds are an enum of the valid knowledg entity 'kind' field

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_kind_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeKindResponse",
            '400': "KnowledgeKnowledgeKindResponse",
            '503': "KnowledgeKnowledgeKindResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_kind_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Knowledge Kinds

        Knowledge kinds are an enum of the valid knowledg entity 'kind' field

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_kind_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeKindResponse",
            '400': "KnowledgeKnowledgeKindResponse",
            '503': "KnowledgeKnowledgeKindResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_kind_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/knowledge/kind/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_schema_get(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of records")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Record offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeEntitySchemasResponse:
        """Get Knowledge Entity Schemas


        :param limit: Maximum number of records
        :type limit: int
        :param offset: Record offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_schema_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntitySchemasResponse",
            '400': "KnowledgeKnowledgeEntitySchemasResponse",
            '503': "KnowledgeKnowledgeEntitySchemasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_schema_get_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of records")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Record offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeEntitySchemasResponse]:
        """Get Knowledge Entity Schemas


        :param limit: Maximum number of records
        :type limit: int
        :param offset: Record offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_schema_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntitySchemasResponse",
            '400': "KnowledgeKnowledgeEntitySchemasResponse",
            '503': "KnowledgeKnowledgeEntitySchemasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_schema_get_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of records")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Record offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Knowledge Entity Schemas


        :param limit: Maximum number of records
        :type limit: int
        :param offset: Record offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_schema_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntitySchemasResponse",
            '400': "KnowledgeKnowledgeEntitySchemasResponse",
            '503': "KnowledgeKnowledgeEntitySchemasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_schema_get_serialize(
        self,
        limit,
        offset,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/knowledge/schema/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_schema_post(
        self,
        request: Annotated[KnowledgeKnowledgeEntitySchemaUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeEntitySchemasUpsertResponse:
        """Upsert a Knowledge Entity Schema


        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntitySchemaUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_schema_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
            '400': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
            '503': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_schema_post_with_http_info(
        self,
        request: Annotated[KnowledgeKnowledgeEntitySchemaUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeEntitySchemasUpsertResponse]:
        """Upsert a Knowledge Entity Schema


        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntitySchemaUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_schema_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
            '400': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
            '503': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_schema_post_without_preload_content(
        self,
        request: Annotated[KnowledgeKnowledgeEntitySchemaUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upsert a Knowledge Entity Schema


        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntitySchemaUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_schema_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
            '400': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
            '503': "KnowledgeKnowledgeEntitySchemasUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_schema_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/knowledge/schema/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_type_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeTypeResponse:
        """Get Knowledge Types

        Knowledge Types are a sub-classification under kind.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_type_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeTypeResponse",
            '400': "KnowledgeKnowledgeTypeResponse",
            '503': "KnowledgeKnowledgeTypeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_type_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeTypeResponse]:
        """Get Knowledge Types

        Knowledge Types are a sub-classification under kind.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_type_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeTypeResponse",
            '400': "KnowledgeKnowledgeTypeResponse",
            '503': "KnowledgeKnowledgeTypeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_type_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Knowledge Types

        Knowledge Types are a sub-classification under kind.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_type_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeTypeResponse",
            '400': "KnowledgeKnowledgeTypeResponse",
            '503': "KnowledgeKnowledgeTypeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_type_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/knowledge/type/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_knowledge_type_post(
        self,
        request: Annotated[KnowledgeKnowledgeEntityUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KnowledgeKnowledgeTypeResponse:
        """Get Knowledge Types

        Knowledge Types are a sub-classification under kind.

        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntityUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_type_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeTypeResponse",
            '400': "KnowledgeKnowledgeTypeResponse",
            '503': "KnowledgeKnowledgeTypeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_knowledge_type_post_with_http_info(
        self,
        request: Annotated[KnowledgeKnowledgeEntityUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KnowledgeKnowledgeTypeResponse]:
        """Get Knowledge Types

        Knowledge Types are a sub-classification under kind.

        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntityUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_type_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeTypeResponse",
            '400': "KnowledgeKnowledgeTypeResponse",
            '503': "KnowledgeKnowledgeTypeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_knowledge_type_post_without_preload_content(
        self,
        request: Annotated[KnowledgeKnowledgeEntityUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Knowledge Types

        Knowledge Types are a sub-classification under kind.

        :param request: Body (required)
        :type request: KnowledgeKnowledgeEntityUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_knowledge_type_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KnowledgeKnowledgeTypeResponse",
            '400': "KnowledgeKnowledgeTypeResponse",
            '503': "KnowledgeKnowledgeTypeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_knowledge_type_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/knowledge/type/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


